==> fasc-openapi-java-sdk-5.4.5.0524-sources.jar: com/fasc/open/api/v5_1/req/signtask/GetOwnerDownloadUrlReq.java <==
package com.fasc.open.api.v5_1.req.signtask;

import com.fasc.open.api.bean.common.OpenId;

import java.util.List;

/**
 * @author Fadada
 * 2021/9/11 16:03:06
 */
public class GetOwnerDownloadUrlReq extends SignTaskBaseReq {
    private OpenId ownerId;
    private String id;
    private String fileType;
    private String customName;
    private Boolean compression;
    private Boolean folderBySigntask;
    private List<BatchDownloadInfo> batchDownloadInfo;

    public Boolean getFolderBySigntask() {
        return folderBySigntask;
    }

    public void setFolderBySigntask(Boolean folderBySigntask) {
        this.folderBySigntask = folderBySigntask;
    }

    public List<BatchDownloadInfo> getBatchDownloadInfo() {
        return batchDownloadInfo;
    }

    public void setBatchDownloadInfo(List<BatchDownloadInfo> batchDownloadInfo) {
        this.batchDownloadInfo = batchDownloadInfo;
    }

    public Boolean getCompression() {
        return compression;
    }

    public void setCompression(Boolean compression) {
        this.compression = compression;
    }

    public OpenId getOwnerId() {
        return ownerId;
    }

    public void setOwnerId(OpenId ownerId) {
        this.ownerId = ownerId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }

    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
}

==> fasc-openapi-java-sdk-5.7.2.0815-sources.jar: com/fasc/open/api/v5_1/req/signtask/GetOwnerDownloadUrlReq.java <==
package com.fasc.open.api.v5_1.req.signtask;

import com.fasc.open.api.bean.common.OpenId;

import java.util.List;

/**
 * @author Fadada
 * 2021/9/11 16:03:06
 */
public class GetOwnerDownloadUrlReq extends SignTaskBaseReq {
    private OpenId ownerId;
    private String id;
    private String fileType;
    private String customName;
    private Boolean compression;
    private Boolean folderBySigntask;
    private List<BatchDownloadInfo> batchDownloadInfo;
    private String downloadMode;
    private Boolean returnHash;

    public Boolean getReturnHash() {
        return returnHash;
    }

    public void setReturnHash(Boolean returnHash) {
        this.returnHash = returnHash;
    }

    public String getDownloadMode() {
        return downloadMode;
    }

    public void setDownloadMode(String downloadMode) {
        this.downloadMode = downloadMode;
    }

    public Boolean getFolderBySigntask() {
        return folderBySigntask;
    }

    public void setFolderBySigntask(Boolean folderBySigntask) {
        this.folderBySigntask = folderBySigntask;
    }

    public List<BatchDownloadInfo> getBatchDownloadInfo() {
        return batchDownloadInfo;
    }

    public void setBatchDownloadInfo(List<BatchDownloadInfo> batchDownloadInfo) {
        this.batchDownloadInfo = batchDownloadInfo;
    }

    public Boolean getCompression() {
        return compression;
    }

    public void setCompression(Boolean compression) {
        this.compression = compression;
    }

    public OpenId getOwnerId() {
        return ownerId;
    }

    public void setOwnerId(OpenId ownerId) {
        this.ownerId = ownerId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }

    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
}
